@@ -1,11 +1,11 @@
-# $Id: Filter.pm 2269 2008-01-21 19:09:06Z rcaputo $
+# $Id: Filter.pm,v 1.14 2004/11/16 07:12:40 rcaputo Exp $
 
 package POE::Filter;
 
 use strict;
 
 use vars qw($VERSION);
-$VERSION = do {my($r)=(q$Revision: 2269 $=~/(\d+)/);sprintf"1.%04d",$r};
+$VERSION = do {my@r=(q$Revision: 1.14 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
 
 use Carp qw(croak);
 
@@ -16,34 +16,6 @@ sub new {
   croak "$type is not meant to be used directly";
 }
 
-# Return all the messages possible to parse in the current input
-# buffer.  This uses the newer get_one_start() and get_one(), which is
-# implementation dependent.
-
-sub get {
-  my ($self, $stream) = @_;
-  my @return;
-
-  $self->get_one_start($stream);
-  while (1) {
-    my $next = $self->get_one();
-    last unless @$next;
-    push @return, @$next;
-  }
-
-  return \@return;
-}
-
-sub clone {
-  my $self = shift;
-  my $buf = (ref($self->[0]) eq 'ARRAY') ? [ ] : '';
-  my $nself = bless [
-    $buf,                     # BUFFER
-    @$self[1..$#$self],  # everything else
-  ], ref $self;
-  return $nself;
-}
-
 #------------------------------------------------------------------------------
 1;
 
@@ -73,8 +45,7 @@ business of using lines.
 =head1 PUBLIC FILTER METHODS
 
 These methods are the generic Filter interface, and every filter must
-implement them or inherit them from this base class.  Specific filters
-may have additional methods.
+implement them.  Specific filters may have additional methods.
 
 =over 2
 
@@ -166,15 +137,6 @@ Adding a handshake protocol means the sender will wait until a filter
 change has been acknowledged before going ahead and sending data in
 the new format.
 
-=item clone
-
-clone() makes a copy of the filter, and clears the copy's buffer.
-
-3rd party modules can either implement their own clone() or inherit
-from POE::Filter.  If inheriting, the object MUST be an array-ref
-AND the first element must be the buffer.  The buffer can be either a
-string or an array-ref.
-
 =back
 
 =head1 SEE ALSO
@@ -192,6 +154,3 @@ block protocols tend to be incompatible.
 Please see L<POE> for more information about authors and contributors.
 
 =cut
-
-# rocco // vim: ts=2 sw=2 expandtab
-# TODO - Redocument.
