@@ -1,9 +1,16 @@
-# $Id: Resource.pm 2220 2007-08-19 00:59:33Z rcaputo $
+# $Id: Resource.pm,v 1.3 2003/11/21 05:08:25 rcaputo Exp $
 
 package POE::Resource;
 
 use vars qw($VERSION);
-$VERSION = do {my($r)=(q$Revision: 2220 $=~/(\d+)/);sprintf"1.%04d",$r};
+$VERSION = do {my@r=(q$Revision: 1.3 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
+
+use Carp qw(croak);
+
+sub new {
+  my $type = shift;
+  croak "$type is a virtual base class and not meant to be used directly";
+}
 
 1;
 
@@ -86,6 +93,3 @@ Please see L<POE> for more information about its authors,
 contributors, and POE's licensing.
 
 =cut
-
-# rocco // vim: ts=2 sw=2 expandtab
-# TODO - Redocument.
