@@ -1,11 +1,11 @@
-# $Id: Events.pm 2284 2008-03-10 08:04:27Z rcaputo $
+# $Id: Events.pm,v 1.13 2004/11/16 07:54:11 teknikill Exp $
 
 # Data and accessors to manage POE's events.
 
-package POE::Resource::Events;
+package POE::Resources::Events;
 
 use vars qw($VERSION);
-$VERSION = do {my($r)=(q$Revision: 2284 $=~/(\d+)/);sprintf"1.%04d",$r};
+$VERSION = do {my@r=(q$Revision: 1.13 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
 
 # These methods are folded into POE::Kernel;
 package POE::Kernel;
@@ -53,7 +53,7 @@ sub _data_ev_finalize {
 sub _data_ev_enqueue {
   my (
     $self, $session, $source_session, $event, $type, $etc, $file, $line,
-    $fromstate, $time
+	$fromstate, $time
   ) = @_;
 
   if (ASSERT_DATA) {
@@ -123,7 +123,7 @@ sub _data_ev_clear_session {
   croak if delete $post_count{$session};
 }
 
-# TODO Alarm maintenance functions may move out to a separate
+# -><- Alarm maintenance functions may move out to a separate
 # POE::Resource module in the future.  Why?  Because alarms may
 # eventually be managed by something other than the event queue.
 # Especially if we incorporate a proper Session scheduler.  Be sure to
@@ -150,7 +150,7 @@ sub _data_ev_clear_alarm_by_name {
 
 ### Remove a specific alarm by its ID.  This is in the events section
 ### because alarms are currently implemented as events with future due
-### times.  TODO It's possible to remove non-alarms; is that wrong?
+### times.  -><- It's possible to remove non-alarms; is that wrong?
 
 sub _data_ev_clear_alarm_by_id {
   my ($self, $session, $alarm_id) = @_;
@@ -162,13 +162,6 @@ sub _data_ev_clear_alarm_by_id {
   my ($time, $id, $event) = $kr_queue->remove_item($alarm_id, $my_alarm);
   return unless defined $time;
 
-  if (TRACE_EVENTS) {
-    _warn(
-      "<ev> removed event $id ``", $event->[EV_NAME], "'' to ",
-      $self->_data_alias_loggable($session), " at $time"
-    );
-  }
-
   $self->_data_ev_refcount_dec( @$event[EV_SOURCE, EV_SESSION] );
   return ($time, $event);
 }
@@ -240,8 +233,7 @@ sub _data_ev_dispatch_due {
   }
 
   my $now = time();
-  my $next_time;
-  while (defined($next_time = $kr_queue->get_next_priority())) {
+  while (defined(my $next_time = $kr_queue->get_next_priority())) {
     last if $next_time > $now;
 
     my ($due_time, $id, $event) = $kr_queue->dequeue_next();
@@ -262,30 +254,6 @@ sub _data_ev_dispatch_due {
 
     $self->_data_ev_refcount_dec($event->[EV_SOURCE], $event->[EV_SESSION]);
     $self->_dispatch_event(@$event, $due_time, $id);
-
-    # An exception occurred.
-    if ($POE::Kernel::kr_exception) {
-
-      # Save the exception lexically, then clear it so it doesn't
-      # linger if run() is called again.
-      my $exception = $POE::Kernel::kr_exception;
-      $POE::Kernel::kr_exception = undef;
-
-      # Stop the kernel.  Cleans out all sessions.
-      POE::Kernel->stop();
-
-      # Throw the exception from way out here.
-      die $exception;
-    }
-  }
-
-  # Tell the event loop to wait for the next event, if there is one.
-  # Otherwise we're going to wait indefinitely for some other event.
-  if (defined $next_time) {
-    $self->loop_reset_time_watcher($next_time);
-  }
-  else {
-    $self->loop_pause_time_watcher();
   }
 }
 
@@ -295,7 +263,7 @@ __END__
 
 =head1 NAME
 
-POE::Resource::Events - manage events for POE::Kernel
+POE::Resources::Events - manage events for POE::Kernel
 
 =head1 SYNOPSIS
 
@@ -321,6 +289,3 @@ Probably.
 Please see L<POE> for more information about authors and contributors.
 
 =cut
-
-# rocco // vim: ts=2 sw=2 expandtab
-# TODO - Redocument.
