@@ -1,12 +1,12 @@
-# $Id: FileHandles.pm 2274 2008-02-25 05:56:36Z rcaputo $
+# $Id: FileHandles.pm,v 1.18 2004/11/22 00:08:06 rcaputo Exp $
 
 # Manage file handles, associated descriptors, and read/write modes
 # thereon.
 
-package POE::Resource::FileHandles;
+package POE::Resources::FileHandles;
 
 use vars qw($VERSION);
-$VERSION = do {my($r)=(q$Revision: 2274 $=~/(\d+)/);sprintf"1.%04d",$r};
+$VERSION = do {my@r=(q$Revision: 1.18 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
 
 # These methods are folded into POE::Kernel;
 package POE::Kernel;
@@ -20,8 +20,8 @@ use strict;
 
 BEGIN {
   if (RUNNING_IN_HELL) {
-    eval '*F_GETFL = sub () { 0 };';
-    eval '*F_SETFL = sub () { 0 };';
+    eval '*F_GETFL = sub { 0 };';
+    eval '*F_SETFL = sub { 0 };';
   }
 }
 
@@ -48,7 +48,6 @@ sub FMO_SESSIONS     () { 4      }  #     { $session_watching_this_handle =>
 sub HSS_HANDLE       () { 0      }  #         [ $blessed_handle,
 sub HSS_SESSION      () { 1      }  #           $blessed_session,
 sub HSS_STATE        () { 2      }  #           $event_name,
-sub HSS_ARGS         () { 3      }  #           \@callback_arguments
                                     #         ],
                                     #       },
 # --- CEASE SUB STRUCT 2 ---        #     },
@@ -88,8 +87,9 @@ sub SH_MODECOUNT  () {  2 } #          [ $read_reference_count,     (MODE_RD)
                             #    },
 
 sub _data_handle_preload {
-  $poe_kernel->[KR_FILENOS] = \%kr_filenos;
+    $poe_kernel->[KR_FILENOS] = \%kr_filenos;
 }
+use POE::API::ResLoader \&_data_handle_preload;
 
 ### Begin-run initialization.
 
@@ -121,7 +121,6 @@ sub _data_handle_finalize {
           "!!!\t\t\thandle  = $hnd_rec->[HSS_HANDLE]\n",
           "!!!\t\t\tsession = $hnd_rec->[HSS_SESSION]\n",
           "!!!\t\t\tevent   = $hnd_rec->[HSS_STATE]\n",
-          "!!!\t\t\targs    = (@{$hnd_rec->[HSS_ARGS]})\n",
         );
       }
     }
@@ -138,7 +137,6 @@ sub _data_handle_finalize {
           "!!!\t\t\thandle  = $hnd_rec->[HSS_HANDLE]\n",
           "!!!\t\t\tsession = $hnd_rec->[HSS_SESSION]\n",
           "!!!\t\t\tevent   = $hnd_rec->[HSS_STATE]\n",
-          "!!!\t\t\targs    = (@{$hnd_rec->[HSS_ARGS]})\n",
         );
       }
     }
@@ -155,7 +153,6 @@ sub _data_handle_finalize {
           "!!!\t\t\thandle  = $hnd_rec->[HSS_HANDLE]\n",
           "!!!\t\t\tsession = $hnd_rec->[HSS_SESSION]\n",
           "!!!\t\t\tevent   = $hnd_rec->[HSS_STATE]\n",
-          "!!!\t\t\targs    = (@{$hnd_rec->[HSS_ARGS]})\n",
         );
       }
     }
@@ -248,7 +245,6 @@ sub _data_handle_enqueue_ready {
         $select->[HSS_STATE], ET_SELECT,
         [ $select->[HSS_HANDLE],  # EA_SEL_HANDLE
           $mode,                  # EA_SEL_MODE
-          @{$select->[HSS_ARGS]}, # EA_SEL_ARGS
         ],
         __FILE__, __LINE__, undef, time(),
       );
@@ -289,7 +285,7 @@ sub _data_handle_is_good {
 ### Add a select to the session, and possibly begin a watcher.
 
 sub _data_handle_add {
-  my ($self, $handle, $mode, $session, $event, $args) = @_;
+  my ($self, $handle, $mode, $session, $event) = @_;
   my $fd = fileno($handle);
 
   # First time watching the file descriptor.  Do some heavy setup.
@@ -350,13 +346,11 @@ sub _data_handle_add {
         my $set_it = "1";
 
         # 126 is FIONBIO (some docs say 0x7F << 16)
-        ioctl(
-          $handle,
-          0x80000000 | (4 << 16) | (ord('f') << 8) | 126,
-          \$set_it
-        ) or _trap(
-          "ioctl($handle, FIONBIO, $set_it) fails: errno " . ($!+0) . " = $!\n"
-        );
+        ioctl( $handle,
+               0x80000000 | (4 << 16) | (ord('f') << 8) | 126,
+               $set_it
+             )
+          or _trap "ioctl($handle, FIONBIO, $set_it) fails: $!\n";
       }
     }
 
@@ -409,45 +403,18 @@ sub _data_handle_add {
             $why = "closed";
           }
           elsif (fileno($handle) == fileno($other_handle)) {
-            $why = "open";
+            $why = "still open";
           }
           else {
-            $why = "open with different file descriptor";
+            $why = "open as different fd";
           }
 
-          if ($session eq $watch_session) {
-            _die(
-              "A session was caught watching two different file handles that\n",
-              "reference the same file descriptor in the same mode ($mode).\n",
-              "This error is usually caused by a file descriptor leak.  The\n",
-              "most common cause is explicitly closing a filehandle without\n",
-              "first unregistering it from POE.\n",
-              "\n",
-              "Some possibly helpful information:\n",
-              "  Session    : ", $self->_data_alias_loggable($session), "\n",
-              "  Old handle : $other_handle (currently $why)\n",
-              "  New handle : $handle\n",
-              "\n",
-              "Please correct the program and try again.\n",
-            );
-          }
-          else {
-            _die(
-              "Two sessions were caught watching the same file descriptor\n",
-              "in the same mode ($mode).  This error is usually caused by\n",
-              "a file descriptor leak.  The most common cause is explicitly\n",
-              "closing a filehandle without first unregistering it from POE.\n",
-              "\n",
-              "Some possibly helpful information:\n",
-              "  Old session: ",
-              $self->_data_alias_loggable($hdl_rec->[HSS_SESSION]), "\n",
-              "  Old handle : $other_handle (currently $why)\n",
-              "  New session: ", $self->_data_alias_loggable($session), "\n",
-              "  New handle : $handle\n",
-              "\n",
-              "Please correct the program and try again.\n",
-            );
-          }
+          _trap(
+            $self->_data_alias_loggable($session),
+            " can't watch $handle in mode $mode: ",
+            $self->_data_alias_loggable($hdl_rec->[HSS_SESSION]),
+            " is already watching it as $other_handle ($why)"
+          );
         }
       }
       _trap "internal inconsistency";
@@ -458,12 +425,11 @@ sub _data_handle_add {
   # the session/handle pair.
 
   else {
-    $kr_fno_rec->[FMO_SESSIONS]->{$session}->{$handle} = [
-      $handle,   # HSS_HANDLE
-      $session,  # HSS_SESSION
-      $event,    # HSS_STATE
-      $args,     # HSS_ARGS
-    ];
+    $kr_fno_rec->[FMO_SESSIONS]->{$session}->{$handle} =
+      [ $handle,   # HSS_HANDLE
+        $session,  # HSS_SESSION
+        $event,    # HSS_STATE
+      ];
 
     # Fix reference counts.
     $kr_fileno->[FNO_TOT_REFCOUNT]++;
@@ -483,14 +449,14 @@ sub _data_handle_add {
   # register the filehandle in the session's structure.
 
   unless (exists $kr_ses_to_handle{$session}->{$handle}) {
-    $kr_ses_to_handle{$session}->{$handle} = [
-      $handle,  # SH_HANDLE
-      0,        # SH_REFCOUNT
-      [ 0,      # SH_MODECOUNT / MODE_RD
-        0,      # SH_MODECOUNT / MODE_WR
-        0       # SH_MODECOUNT / MODE_EX
-      ]
-    ];
+    $kr_ses_to_handle{$session}->{$handle} =
+      [ $handle,  # SH_HANDLE
+        0,        # SH_REFCOUNT
+        [ 0,      # SH_MODECOUNT / MODE_RD
+          0,      # SH_MODECOUNT / MODE_WR
+          0       # SH_MODECOUNT / MODE_EX
+        ]
+      ];
     $self->_data_ses_refcount_inc($session);
   }
 
@@ -624,7 +590,7 @@ sub _data_handle_remove {
   }
 
   # SS_HANDLES - Remove the select from the session, assuming there is
-  # a session to remove it from.  TODO Key it on fileno?
+  # a session to remove it from.  -><- Key it on fileno?
 
   if (
     exists($kr_ses_to_handle{$session}) and
@@ -752,7 +718,7 @@ sub _data_handle_clear_session {
   }
 }
 
-# TODO Testing accessors.  Maybe useful for introspection.  May need
+# -><- Testing accessors.  Maybe useful for introspection.  May need
 # modification before that.
 
 sub _data_handle_fno_refcounts {
@@ -807,7 +773,7 @@ __END__
 
 =head1 NAME
 
-POE::Resource::FileHandles - manage file handles on behalf of POE::Kernel
+POE::Resources::FileHandles - manage file handles on behalf of POE::Kernel
 
 =head1 SYNOPSIS
 
@@ -834,6 +800,3 @@ Probably.
 Please see L<POE> for more information about authors and contributors.
 
 =cut
-
-# rocco // vim: ts=2 sw=2 expandtab
-# TODO - Redocument.
